==> nextcloud-24.0.5.tgz: nextcloud/apps/user_status/l10n/sv.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Senaste statusuppdateringar",
    "In a meeting" : "På ett möte",
    "Commuting" : "Reser",
    "Out sick" : "Sjuk",
    "Vacationing" : "På semester",
    "Working remotely" : "Arbetar hemifrån",
    "In a call" : "I ett samtal",
    "User status" : "Användarstatus",
    "View profile" : "Visa profil",
    "Clear status after" : "Rensa status efter",
    "What is your status?" : "Vad är din status?",
    "Set status" : "Sätt status",
    "Online status" : "Online-status",
    "Status message" : "Statusmeddelande",
    "Clear status message" : "Rensa statusmeddelande",
    "Set status message" : "Sätt statusmeddelande",
    "There was an error saving the status" : "Ett fel inträffade när statusen skulle ändras",
    "There was an error clearing the status" : "Ett fel inträffade när statusen skulle rensas",
    "No recent status changes" : "Inga statusuppdateringar den sista tiden",
    "Away" : "Iväg",
    "Do not disturb" : "Stör ej",
    "{status}, {timestamp}" : "{status}, {timestamp}",
    "Don't clear" : "Rensa inte",
    "Today" : "Idag",
    "This week" : "Denna vecka",
    "Online" : "Online",
    "Invisible" : "Osynlig",
    "Offline" : "Frånkopplad",
    "There was an error saving the new status" : "Ett fel inträffade när den nya statusen skulle sparas",
    "30 minutes" : "30 minuter",
    "1 hour" : "1 timme",
    "4 hours" : "4 timmar",
    "Mute all notifications" : "Dölj alla aviseringar",
    "Appear offline" : "Visa som frånkopplad",
    "Clear status message after" : "Rensa statusmeddelande efter",
    "What's your status?" : "Vad är din status?"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-25.0.12.tgz: nextcloud/apps/user_status/l10n/sv.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Senaste statusuppdateringar",
    "No recent status changes" : "Inga statusuppdateringar den sista tiden",
    "In a meeting" : "På ett möte",
    "Commuting" : "Reser",
    "Out sick" : "Sjuk",
    "Vacationing" : "På semester",
    "Working remotely" : "Arbetar hemifrån",
    "In a call" : "I ett samtal",
    "User status" : "Användarstatus",
    "View profile" : "Visa profil",
    "Clear status after" : "Rensa status efter",
    "Emoji for your status message" : "Emoji för ditt statusmeddelande",
    "What is your status?" : "Vad är din status?",
    "Predefined statuses" : "Fördefinierade statusar",
    "Previously set" : "Tidigare inställd",
    "Reset status" : "Återställ status",
    "Set status" : "Sätt status",
    "Online status" : "Online-status",
    "Status message" : "Statusmeddelande",
    "Your status was set automatically" : "Din status ställdes in automatiskt",
    "Clear status message" : "Rensa statusmeddelande",
    "Set status message" : "Sätt statusmeddelande",
    "Reset status to \"{icon} {message}\"" : "Återställ status till \"{icon} {message}\"",
    "Reset status to \"{message}\"" : "Återställ status till \"{message}\"",
    "Reset status to \"{icon}\"" : "Återställ status till \"{icon}\"",
    "There was an error saving the status" : "Ett fel inträffade när statusen skulle ändras",
    "There was an error clearing the status" : "Ett fel inträffade när statusen skulle rensas",
    "There was an error reverting the status" : "Det gick inte att återställa statusen",
    "Don't clear" : "Rensa inte",
    "Today" : "Idag",
    "This week" : "Denna vecka",
    "Online" : "Online",
    "Away" : "Iväg",
    "Do not disturb" : "Stör ej",
    "Invisible" : "Osynlig",
    "Offline" : "Frånkopplad",
    "There was an error saving the new status" : "Ett fel inträffade när den nya statusen skulle sparas",
    "30 minutes" : "30 minuter",
    "1 hour" : "1 timme",
    "4 hours" : "4 timmar",
    "Mute all notifications" : "Dölj alla aviseringar",
    "Appear offline" : "Visa som frånkopplad",
    "{status}, {timestamp}" : "{status}, {timestamp}"
},
"nplurals=2; plural=(n != 1);");
